% Auto-generated chapter 11 for ibnmajah
% Hadiths in this chapter: 47

\hadithdefcmd{ibnmajah}{2090}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُصْعَبٍ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رِفَاعَةَ الْجُهَنِيِّ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا حَلَفَ قَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ ‏"‏ ‏.‏\hadithno{2090}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rifa'ah Al - Juhani said:"When the Prophet (ﷺ) took an oath he would say: 'By the One in Whose Hand is the soul of Muhammad}}
\hadithdefcmd{ibnmajah}{2091}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الصَّنْعَانِيُّ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رِفَاعَةَ بْنِ عَرَابَةَ الْجُهَنِيِّ، قَالَ كَانَتْ يَمِينُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ التَّى يَحْلِفُ بِهَا أَشْهَدُ عِنْدَ اللَّهِ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ ‏"‏ ‏.‏\hadithno{2091}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rifa'ah bin 'Arabah A-Juhani said:"The swearing of the Messenger of Allah (ﷺ) when he took an oath and I bear witness before Allah was: 'By the One in Whose Hand is my soul}}
\hadithdefcmd{ibnmajah}{2092}{حَدَّثَنَا أَبُو إِسْحَاقَ الشَّافِعِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ الْعَبَّاسِ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ عَبَّادِ بْنِ إِسْحَاقَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَتْ أَكْثَرُ أَيْمَانِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ وَمُصَرِّفِ الْقُلُوبِ ‏"‏ ‏.‏\hadithno{2092}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salim that his father said:"The swearing most frequently sworn by the Messenger of Allah (ﷺ) was: 'No, by the Controller of the hearts}}
\hadithdefcmd{ibnmajah}{2093}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ، ح وَحَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، جَمِيعًا عَنْ مُحَمَّدِ بْنِ هِلاَلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَتْ يَمِينُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ وَأَسْتَغْفِرُ اللَّهَ ‏"‏ ‏.‏\hadithno{2093}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The swearing of the Messenger of Allah (ﷺ) was: 'No, and I ask Allah for forgiveness}}
\hadithdefcmd{ibnmajah}{2094}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ سَمِعَهُ يَحْلِفُ بِأَبِيهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ قَالَ عُمَرُ فَمَا حَلَفْتُ بِهَا ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{2094}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim bin 'Abdullah bin 'Umar, from his father, from 'Umar, that :the Messenger of Allah (ﷺ) heard him swearing by his father. The Messenger of Allah (ﷺ) said: 'Allah forbids you from making oaths by your forefathers." 'Umar said: I never took an oath by them (i.e., my forefathers) myself nor narrating such words from anyone else.”}}
\hadithdefcmd{ibnmajah}{2095}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَحْلِفُوا بِالطَّوَاغِي وَلاَ بِآبَائِكُمْ ‏"‏ ‏.‏\hadithno{2095}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdur-Rahman bin Samurah that :the Messenger of Allah (ﷺ) said: 'Do not take oaths by idols nor by your forefathers}}
\hadithdefcmd{ibnmajah}{2096}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ حَلَفَ فَقَالَ فِي يَمِينِهِ بِاللاَّتِ وَالْعُزَّى فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{2096}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that :the Messenger of Allah (ﷺ) said: "Whoever takes an oath, and swears, saying: 'By Al-Lat and Al-Uzza,' let him say:'La ilaha illallah}}
\hadithdefcmd{ibnmajah}{2097}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ حَلَفْتُ بِاللاَّتِ وَالْعُزَّى فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ثُمَّ انْفُثْ عَنْ يَسَارِكَ ثَلاَثًا وَتَعَوَّذْ وَلاَ تَعُدْ ‏"‏ ‏.‏\hadithno{2097}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'd said:"I took an oath by Lat and 'Uzza. The Messenger of Allah (ﷺ) said : 'Say: "La ilaha illallah wahdahu la sharika lahu" (None has the right to be worshipped but Allah alone, with no partner or associate)," then spit toward your left three times, and seek refuge with Allah, and do not do that again}}
\hadithdefcmd{ibnmajah}{2098}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَلَفَ بِمِلَّةٍ سِوَى الإِسْلاَمِ كَاذِبًا مُتَعَمِّدًا فَهُوَ كَمَا قَالَ ‏"‏ ‏.‏\hadithno{2098}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Thabit bin Ad-Dahhak said:The Messenger of Allah (ﷺ) said: 'Whoever takes an oath to follow a religion other than Islam, telling a deliberate lie, he will be as he said}}
\hadithdefcmd{ibnmajah}{2099}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا بَقِيَّةُ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَرَّرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ سَمِعَ النَّبِيُّ ـ صلى الله عليه وسلم ـ رَجُلاً يَقُولُ أَنَا إِذًا لَيَهُودِيٌّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ وَجَبَتْ ‏"‏ ‏.‏\hadithno{2099}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) heard a man say:"If that happens, I will be a Jew." The Messenger of Allah (ﷺ) said: 'That is guaranteed}}
\hadithdefcmd{ibnmajah}{2100}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ الْبَجَلِيُّ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ قَالَ إِنِّي بَرِيءٌ مِنَ الإِسْلاَمِ فَإِنْ كَانَ كَاذِبًا فَهُوَ كَمَا قَالَ وَإِنْ كَانَ صَادِقًا لَمْ يَعُدْ إِلَيْهِ الإِسْلاَمُ سَالِمًا ‏"‏ ‏.‏\hadithno{2100}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abdullah bin Buraidah that his father told that :the Messenger of Allah (ﷺ) said: "Whoever says: 'I have nothing to do with Islam,' if he is lying then he is as he said, and if he is telling the truth, his Islam will not be sound}}
\hadithdefcmd{ibnmajah}{2101}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعَ النَّبِيُّ ـ صلى الله عليه وسلم ـ رَجُلاً يَحْلِفُ بِأَبِيهِ فَقَالَ ‏ "‏ لاَ تَحْلِفُوا بِآبَائِكُمْ مَنْ حَلَفَ بِاللَّهِ فَلْيَصْدُقْ وَمَنْ حُلِفَ لَهُ بِاللَّهِ فَلْيَرْضَ وَمَنْ لَمْ يَرْضَ بِاللَّهِ فَلَيْسَ مِنَ اللَّهِ ‏"‏ ‏.‏\hadithno{2101}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) heard a man taking an oath by his father and said: 'Do not make oaths by your forefathers. Whoever makes an oath by Allah, let him fulfill his oath, and if an oath is sworn for a person by Allah, let him accept it. Whoever is not content with Allah has nothing to do with Allah}}
\hadithdefcmd{ibnmajah}{2102}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي بَكْرِ بْنِ يَحْيَى بْنِ النَّضْرِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ رَأَى عِيسَى ابْنُ مَرْيَمَ رَجُلاً يَسْرِقُ فَقَالَ أَسَرَقْتَ قَالَ لاَ وَالَّذِي لاَ إِلَهَ إِلاَّ هُوَ ‏.‏ فَقَالَ عِيسَى آمَنْتُ بِاللَّهِ وَكَذَّبْتُ بَصَرِي ‏"‏ ‏.‏\hadithno{2102}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Eisa bin Maryam saw a man stealing and said: 'Did you steal?' He said: 'No, by the One besides Whom there is no other God.' 'Eisa said: 'I believe in Allah, and I do not believe what my eyes see}}
\hadithdefcmd{ibnmajah}{2103}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ بَشَّارِ بْنِ كِدَامٍ، عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا الْحَلِفُ حِنْثٌ أَوْ نَدَمٌ ‏"‏ ‏.‏\hadithno{2103}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that :the Messenger of Allah (ﷺ) said: "An oath (leads to) either sin or regret}}
\hadithdefcmd{ibnmajah}{2104}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَلَفَ فَقَالَ إِنْ شَاءَ اللَّهُ فَلَهُ ثُنْيَاهُ ‏"‏ ‏.‏\hadithno{2104}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:'Whoever swears an oath and says In sha' Allah, he will have made an exception}}
\hadithdefcmd{ibnmajah}{2105}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَلَفَ وَاسْتَثْنَى إِنْ شَاءَ رَجَعَ وَإِنْ شَاءَ تَرَكَ غَيْرُ حَانِثٍ ‏"‏ ‏.‏\hadithno{2105}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"Whoever swears an oath and says In sha' Allah, if he wishes he may go ahead and if he wishes he may not, without having broken his oath}}
\hadithdefcmd{ibnmajah}{2106}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رِوَايَةً قَالَ ‏ "‏ مَنْ حَلَفَ وَاسْتَثْنَى فَلَمْ يَحْنَثْ ‏"‏ ‏.‏\hadithno{2106}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar:"Whoever swears an oath and says In sha' Allah, will never break his oath}}
\hadithdefcmd{ibnmajah}{2107}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ أَبِي مُوسَى، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ نَسْتَحْمِلُهُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ وَاللَّهِ مَا أَحْمِلُكُمْ وَمَا عِنْدِي مَا أَحْمِلُكُمْ عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَلَبِثْنَا مَا شَاءَ اللَّهُ ثُمَّ أُتِيَ بِإِبِلٍ فَأَمَرَ لَنَا بِثَلاَثَةِ إِبِلٍ ذَوْدٍ غُرِّ الذُّرَى فَلَمَّا انْطَلَقْنَا قَالَ بَعْضُنَا لِبَعْضٍ أَتَيْنَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَسْتَحْمِلُهُ فَحَلَفَ أَلاَّ يَحْمِلَنَا ثُمَّ حَمَلَنَا ارْجِعُوا بِنَا ‏.‏ فَأَتَيْنَاهُ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّا أَتَيْنَاكَ نَسْتَحْمِلُكَ فَحَلَفْتَ أَنْ لاَ تَحْمِلَنَا ‏.‏ ثُمَّ حَمَلْتَنَا فَقَالَ ‏"‏ وَاللَّهِ مَا أَنَا حَمَلْتُكُمْ فَإِنَّ اللَّهَ حَمَلَكُمْ وَاللَّهِ مَا أَنَا حَمَلْتُكُمْ بَلِ اللَّهُ حَمَلَكُمْ إِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ كَفَّرْتُ عَنْ يَمِينِي وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَكَفَّرْتُ عَنْ يَمِينِي ‏"‏ ‏.‏\hadithno{2107}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Burdah that his father Abu Musa said:"I came to the Messenger of Allah (ﷺ) with a group of Asharites and asked him to give us animals to ride. He said: 'By Allah, I cannot give you anything to ride, and I have nothing to give you to ride.' We stayed as long as Allah willed, then some camels were brought to him. He ordered that we be given three she-camels with fine humps. When we left, we said to one another: 'We came to the Messenger of Allah (ﷺ) to ask him for animals to ride, and he swore by Allah that he would not give us anything to ride, then he gave us something. Let us go back.' So we went to him and we said: 'O Messenger of Allah! We came to you seeking mounts, and you took an oath that you would not give us mounts, then you gave us some mounts.' He said: 'By Allah, I did not give you animals to ride, rather Allah gave you them to ride. I, by Allah, if Allah wills, do not swear and then see something better than it, but I offer expiation for what I swore about, and do that which is better.' Or he said: 'I do that which is better and offer expiation for what I swore about}}
\hadithdefcmd{ibnmajah}{2108}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَأْتِ الَّذِي هُوَ خَيْرٌ وَلْيُكَفِّرْ عَنْ يَمِينِهِ ‏"‏ ‏.‏\hadithno{2108}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Adi bin Hatim that :the Messenger of Allah (ﷺ), said: "Whoever swears an oath then sees that something else is better than it, let him do that which is better and offer expiation for what he swore about}}
\hadithdefcmd{ibnmajah}{2109}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا أَبُو الزَّعْرَاءِ، عَمْرُو بْنُ عَمْرٍو عَنْ عَمِّهِ أَبِي الأَحْوَصِ، عَوْفِ بْنِ مَالِكٍ الْجُشَمِيِّ عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ يَأْتِينِي ابْنُ عَمِّي فَأَحْلِفُ أَنْ لاَ، أُعْطِيَهُ وَلاَ أَصِلَهُ ‏.‏ قَالَ ‏ "‏ كَفِّرْ عَنْ يَمِينِكَ ‏"‏ ‏.‏\hadithno{2109}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abul-Ahwas 'Awf bin Malik Al- Jushami that his father said:"I said: 'O Messenger of Allah, my cousin comes to me and I swear that I will not give him anything or uphold the ties of kinship with him.' He said: 'Offer expiation for what you swore about}}
\hadithdefcmd{ibnmajah}{2110}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ حَارِثَةَ بْنِ أَبِي الرِّجَالِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ حَلَفَ فِي قَطِيعَةِ رَحِمٍ أَوْ فِيمَا لاَ يَصْلُحُ فَبِرُّهُ أَنْ لاَ يَتِمَّ عَلَى ذَلِكَ ‏"‏ ‏.‏\hadithno{2110}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"Whoever takes an oath to cut off the ties of kinship, or to do something that is not right, the fulfillment of his vow is not to do that}}
\hadithdefcmd{ibnmajah}{2111}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْمُؤْمِنِ الْوَاسِطِيُّ، حَدَّثَنَا عَوْنُ بْنُ عُمَارَةَ، حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَتْرُكْهَا فَإِنَّ تَرْكَهَا كَفَّارَتُهَا ‏"‏ ‏.‏\hadithno{2111}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said that the Prophet (ﷺ) said:"Whoever swears an oath then sees that something else is better than it, let him not do it, and his leaving it is the expiation for it}}
\hadithdefcmd{ibnmajah}{2112}{حَدَّثَنَا الْعَبَّاسُ بْنُ يَزِيدَ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ الْبَكَّائِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ يَعْلَى الثَّقَفِيُّ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَفَّرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِصَاعٍ مِنْ تَمْرٍ وَأَمَرَ النَّاسَ بِذَلِكَ فَمَنْ لَمْ يَجِدْ فَنِصْفُ صَاعٍ مِنْ بُرٍّ ‏.‏\hadithno{2112}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abbas said:"The Messenger of Allah (ﷺ) offered expiation of a Sa' of dates, and he enjoined the people to do likewise. Whoever does not have that (must give) half a Sa' of wheat}}
\hadithdefcmd{ibnmajah}{2113}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ بْنِ أَبِي الْمُغِيرَةِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ الرَّجُلُ يَقُوتُ أَهْلَهُ قُوتًا فِيهِ سَعَةٌ وَكَانَ الرَّجُلُ يَقُوتُ أَهْلَهُ قُوتًا فِيهِ شِدَّةٌ فَنَزَلَتْ ‏\{مِنْ أَوْسَطِ مَا تُطْعِمُونَ أَهْلِيكُمْ\}‏ ‏.‏\hadithno{2113}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man would give his family food that was abundant and another would give his family food that was barely sufficient, then the following was revealed: 'With the Awsat of that with which you feed your families...’”}}
\hadithdefcmd{ibnmajah}{2114}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الْمَعْمَرِيُّ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اسْتَلَجَّ أَحَدُكُمْ فِي الْيَمِينِ فَإِنَّهُ آثَمُ لَهُ عِنْدَ اللَّهِ مِنَ الْكَفَّارَةِ الَّتِي أُمِرَ بِهَا ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ الْوُحَاظِيُّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{2114}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hammam heard Abu Hurairah saying that 'Abul-Qasim (ﷺ) said:"If anyone of you insists on fulfilling what he swore to (after learning that it is wrong) then it is more sinful before Allah than (breaking the oath for which) the expiation that has been enjoined upon him}}
\hadithdefcmd{ibnmajah}{2115}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ صَالِحٍ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِإِبْرَارِ الْمُقْسِمِ ‏.‏\hadithno{2115}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Bara' bin 'Azib said:'The Messenger of Allah (ﷺ) commanded us to help fulfill the oath}}
\hadithdefcmd{ibnmajah}{2116}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ صَفْوَانَ، أَوْ عَنْ صَفْوَانَ بْنِ عَبْدِ الرَّحْمَنِ الْقُرَشِيِّ، قَالَ لَمَّا كَانَ يَوْمُ فَتْحِ مَكَّةَ جَاءَ بِأَبِيهِ فَقَالَ يَا رَسُولَ اللَّهِ اجْعَلْ لأَبِي نَصِيبًا فِي الْهِجْرَةِ ‏.‏ فَقَالَ ‏"‏ إِنَّهُ لاَ هِجْرَةَ ‏"‏ ‏.‏ فَانْطَلَقَ فَدَخَلَ عَلَى الْعَبَّاسِ فَقَالَ قَدْ عَرَفْتَنِي فَقَالَ أَجَلْ ‏.‏ فَخَرَجَ الْعَبَّاسُ فِي قَمِيصٍ لَيْسَ عَلَيْهِ رِدَاءٌ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ عَرَفْتَ فُلاَنًا وَالَّذِي بَيْنَنَا وَبَيْنَهُ جَاءَ بِأَبِيهِ لِيُبَايِعَكَ عَلَى الْهِجْرَةِ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّهُ لاَ هِجْرَةَ ‏"‏ ‏.‏ فَقَالَ الْعَبَّاسُ أَقْسَمْتُ عَلَيْكَ ‏.‏ فَمَدَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَدَهُ فَمَسَّ يَدَهُ فَقَالَ ‏"‏ أَبْرَرْتُ عَمِّي وَلاَ هِجْرَةَ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، عَنْ عَبْدِ اللَّهِ بْنِ إِدْرِيسَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، بِإِسْنَادِهِ نَحْوَهُ ‏.‏ قَالَ يَزِيدُ بْنُ أَبِي زِيَادٍ يَعْنِي لاَ هِجْرَةَ مِنْ دَارٍ قَدْ أَسْلَمَ أَهْلُهَا ‏.‏\hadithno{2116}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mujahid, that 'Abdur-Rahman bin Safwan, or Safwan bin 'Abdur- Rahman Al-Qurashi said:"On the Day of the conquest of Makkah, he came with his father and he said: 'O Messenger of Allah, give my father a share of Hijrah.' He said: 'There is no Hijrah.' Then he went away and entered upon 'Abbas and said: 'Do you know who I am?' He said: 'Yes.' Then 'Abbas went out, wearing a shirt and no upper wrap, and said: 'O Messenger of Allah, do you know so-and-so with whom we have friendly ties? He brought his father to swear an oath of allegiance (i.e., promise) to emigrate.' The Prophet (ﷺ) said: 'There is no Hijrah.'" 'Abbas said: 'I adjure you to do it.' The Prophet (ﷺ) stretched forth his hand and touched his hand, and said: 'I have fulfilled the oath of my uncle, but there is no Hijrah."' (Da'if)Another chain with similar wording. Yazid bin Abu Ziyad said: "Meaning: There is no Hijrah from a land whose people have accepted Islam}}
\hadithdefcmd{ibnmajah}{2117}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَجْلَحُ الْكِنْدِيُّ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا حَلَفَ أَحَدُكُمْ فَلاَ يَقُلْ مَا شَاءَ اللَّهُ وَشِئْتَ ‏.‏ وَلَكِنْ لِيَقُلْ مَا شَاءَ اللَّهُ ثُمَّ شِئْتَ ‏"‏ ‏.‏\hadithno{2117}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:'When anyone of you swears an oath, let him not say: 'What Allah wills and what you will.' Rather let him say: 'What Allah wills and then what you will}}
\hadithdefcmd{ibnmajah}{2118}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، أَنَّ رَجُلاً، مِنَ الْمُسْلِمِينَ رَأَى فِي النَّوْمِ أَنَّهُ لَقِيَ رَجُلاً مِنْ أَهْلِ الْكِتَابِ فَقَالَ نِعْمَ الْقَوْمُ أَنْتُمْ لَوْلاَ أَنَّكُمْ تُشْرِكُونَ تَقُولُونَ مَا شَاءَ اللَّهُ وَشَاءَ مُحَمَّدٌ ‏.‏ وَذَكَرَ ذَلِكَ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ أَمَا وَاللَّهِ إِنْ كُنْتُ لأَعْرِفُهَا لَكُمْ قُولُوا مَا شَاءَ اللَّهُ ثُمَّ شَاءَ مُحَمَّدٌ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنِ الطُّفَيْلِ بْنِ سَخْبَرَةَ، أَخِي عَائِشَةَ لأُمِّهَا عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{2118}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hudhaifah bin Yaman that :a Muslim man saw in a dream that he met a man from among the People of the Book, who said: "What good people you would be if only you were not committing Shirk. For you say: 'What Allah wills and Muhammad wills."' He mentioned that to the Prophet (ﷺ) and he said: "By Allah, I am aware of that. Say: 'What Allah wills then what Muhammad wills."'Another chain from Tufail bin Sakhbarah, the brother of 'Aishah by her mother, from the Prophet (ﷺ), with similar wording}}
\hadithdefcmd{ibnmajah}{2119}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ، عَنْ إِسْرَائِيلَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الأَعْلَى، عَنْ جَدَّتِهِ، عَنْ أَبِيهَا، سُوَيْدِ بْنِ حَنْظَلَةَ قَالَ خَرَجْنَا نُرِيدُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَمَعَنَا وَائِلُ بْنُ حُجْرٍ فَأَخَذَهُ عَدُوٌّ لَهُ فَتَحَرَّجَ النَّاسُ أَنْ يَحْلِفُوا فَحَلَفْتُ أَنَا أَنَّهُ أَخِي فَخَلَّى سَبِيلَهُ فَأَتَيْنَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَخْبَرْتُهُ أَنَّ الْقَوْمَ تَحَرَّجُوا أَنْ يَحْلِفُوا وَحَلَفْتُ أَنَا أَنَّهُ أَخِي فَقَالَ ‏ "‏ صَدَقْتَ الْمُسْلِمُ أَخُو الْمُسْلِمِ ‏"‏ ‏.‏\hadithno{2119}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Suwaid bin Hanzalah said:"We went out looking for the Messenger of Allah (ﷺ) and Wa'il bin Hujr was with us. An enemy of his seized him and the people were reluctant to swear an oath but I swore that he was my brother, so they set him free. We came to the Messenger of Allah (ﷺ) and I told him that the people had been reluctant to swear an oath, but I had sworn that he was my brother. He said: 'You told the truth. The Muslim is the brother of his fellow Muslim}}
\hadithdefcmd{ibnmajah}{2120}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هُشَيْمٌ، عَنْ عَبَّادِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا الْيَمِينُ عَلَى نِيَّةِ الْمُسْتَحْلِفِ ‏"‏ ‏.‏\hadithno{2120}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"The oath is only according to the intention of the one who requests the oath to be taken}}
\hadithdefcmd{ibnmajah}{2121}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَمِينُكَ عَلَى مَا يُصَدِّقُكَ بِهِ صَاحِبُكَ ‏"‏ ‏.‏\hadithno{2121}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Your oath is as your companion understands it to be}}
\hadithdefcmd{ibnmajah}{2122}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ النَّذْرِ وَقَالَ ‏ "‏ إِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ اللَّئِيمِ ‏"‏ ‏.‏\hadithno{2122}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"The Messenger of Allah (ﷺ) forbade vows and said: 'They are just a means of taking wealth from the miserly}}
\hadithdefcmd{ibnmajah}{2123}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ النَّذْرَ لاَ يَأْتِي ابْنَ آدَمَ بِشَىْءٍ إِلاَّ مَا قُدِّرَ لَهُ وَلَكِنْ يَغْلِبُهُ الْقَدَرُ مَا قُدِّرَ لَهُ فَيُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ فَيَتَيَسَّرُ عَلَيْهِ مَا لَمْ يَكُنْ يَتَيَسَّرُ عَلَيْهِ مِنْ قَبْلِ ذَلِكَ وَقَدْ قَالَ اللَّهُ أَنْفِقْ أُنْفِقْ عَلَيْكَ ‏"‏ ‏.‏\hadithno{2123}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Vows do not bring the son of Adam anything unless it has been decreed for him. But he is dominated by Divine preordainment, and will get what is decreed for him. And (vows) are a means of making the miser give something, so what he desires becomes obtainable for him, which was not obtainable before his vow. And Allah says: 'Spend, I will spend on you}}
\hadithdefcmd{ibnmajah}{2124}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَمِّهِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَلاَ نَذْرَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ ‏"‏ ‏.‏\hadithno{2124}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Imran bin Husain that the Messenger of Allah (ﷺ) said:"[There is no vow to commit disobedience and] no vow concerning that which the son of Adam does not possess}}
\hadithdefcmd{ibnmajah}{2125}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ أَبُو طَاهِرٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{2125}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"There is no vow to commit disobedience, and the expiation (for such a vow) is the expiation for breaking an oath}}
\hadithdefcmd{ibnmajah}{2126}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ وَمَنْ نَذَرَ أَنْ يَعْصِيَ اللَّهَ فَلاَ يَعْصِهِ ‏"‏ ‏.‏\hadithno{2126}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) said:"Whoever vows to obey Allah, let him obey Him, and whoever vows to disobey Allah, let him not disobey Him}}
\hadithdefcmd{ibnmajah}{2127}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ رَافِعٍ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَذَرَ نَذْرًا وَلَمْ يُسَمِّهِ فَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{2127}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Uqbah bin 'Amit Al-Juhani that the Messenger of Allah (ﷺ) said:"Whoever makes a vow and does not state it specifically, the expiation (for such a vow) is the expiation for breaking an oath}}
\hadithdefcmd{ibnmajah}{2128}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الصَّنْعَانِيُّ، حَدَّثَنَا خَارِجَةُ بْنُ مُصْعَبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ نَذَرَ نَذْرًا وَلَمْ يُسَمِّهِ فَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ وَمَنْ نَذَرَ نَذْرًا لَمْ يُطِقْهُ فَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ وَمَنْ نَذَرَ نَذْرًا أَطَاقَهُ فَلْيَفِ بِهِ ‏"‏ ‏.‏\hadithno{2128}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{lt was narrated from Ibn 'Abbas that the Prophet (ﷺ) said:"Whoever makes a vow and does not state it specifically, the expiation (for such a vow) is the expiation for breaking an oath. Whoever makes a vow and is not able to fulfill it, the expiation for that is the expiation for breaking an oath. Whoever makes a vow and is able to fulfill it, let him do so}}
\hadithdefcmd{ibnmajah}{2129}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ نَذَرْتُ نَذْرًا فِي الْجَاهِلِيَّةِ فَسَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ بَعْدَ مَا أَسْلَمْتُ فَأَمَرَنِي أَنْ أُوفِيَ بِنَذْرِي ‏.‏\hadithno{2129}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Umar bin Khattab said:"I made a vow during the Ignorance period and I asked the Prophet (ﷺ) (about it) after I became Muslim. He told me to fulfill my vow}}
\hadithdefcmd{ibnmajah}{2130}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَعَبْدُ اللَّهِ بْنُ إِسْحَاقَ الْجَوْهَرِيُّ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، أَنْبَأَنَا الْمَسْعُودِيُّ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ أَنْ أَنْحَرَ بِبُوَانَةَ فَقَالَ ‏"‏ فِي نَفْسِكَ شَىْءٌ مِنْ أَمْرِ الْجَاهِلِيَّةِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَوْفِ بِنَذْرِكَ ‏"‏ ‏.‏\hadithno{2130}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Abbas that a man came to the Prophet (ﷺ) and said:"O Messenger of Allah, I vowed to offer a sacrifice at Buwanah." He said: "Do you intend any action of Ignorance period?" He said: "No." He said: "Then fulfill your vow}}
\hadithdefcmd{ibnmajah}{2131}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الطَّائِفِيِّ، عَنْ مَيْمُونَةَ بِنْتِ كَرْدَمٍ الْيَسَارِيَّةِ، أَنَّ أَبَاهَا، لَقِيَ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَهِيَ رَدِيفَةٌ لَهُ فَقَالَ إِنِّي نَذَرْتُ أَنْ أَنْحَرَ بِبُوَانَةَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ هَلْ بِهَا وَثَنٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَوْفِ بِنَذْرِكَ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ دُكَيْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ بْنِ مِقْسَمٍ، عَنْ مَيْمُونَةَ بِنْتِ كَرْدَمٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{2131}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Maimunah bint Kardam Al-Yasariyyah that :her father met the Prophet (ﷺ) when she was riding behind him. He said: "I vowed to offer a sacrifice at Buwanah." The Messenger of Allah (ﷺ) said: "Is there any idol there?" He said: "No." He said: " Fulfill your vow." (Hasan)Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{2132}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، اسْتَفْتَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فِي نَذْرٍ كَانَ عَلَى أُمِّهِ تُوُفِّيَتْ وَلَمْ تَقْضِهِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏\hadithno{2132}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas' that :Sa'd bin 'Ubadah asked the Messenger of Allah (ﷺ) about a vow which his mother had made, but she had died without fulfilling it. The Messenger of Allah (ﷺ) said: "Fulfill it on her behalf}}
\hadithdefcmd{ibnmajah}{2133}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، ‏.‏ أَنَّ امْرَأَةً، أَتَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَتْ إِنَّ أُمِّي تُوُفِّيَتْ وَعَلَيْهَا نَذْرُ صِيَامٍ فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لِيَصُمْ عَنْهَا الْوَلِيُّ ‏"‏ ‏.‏\hadithno{2133}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Abdullsh that :a woman came to the Messenger of Allah (ﷺ) and said: "My mother has died, and she had made a vow to fast, but she died before she could fulfill it. The Messenger of Allah (ﷺ) said: 'Let her guardian fast on her behalf}}
\hadithdefcmd{ibnmajah}{2134}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ أَبِي سَعِيدٍ الرُّعَيْنِيِّ، أَنَّ عَبْدَ اللَّهِ بْنَ مَالِكٍ، أَخْبَرَهُ أَنَّ عُقْبَةَ بْنَ عَامِرٍ أَخْبَرَهُ أَنَّ أُخْتَهُ نَذَرَتْ أَنْ تَمْشِيَ حَافِيَةً غَيْرَ مُخْتَمِرَةٍ وَأَنَّهُ ذَكَرَ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ مُرْهَا فَلْتَرْكَبْ وَلْتَخْتَمِرْ وَلْتَصُمْ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏\hadithno{2134}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed Ar-Ru'aini that 'Abdullah bin Malik told him, that :'Uqbah bin 'Amir told him, that his sister vowed to walk, barefoot and bareheaded, and he mentioned that to the Messenger of Allah (ﷺ) He said: "Order her to ride and to cover her head, and to fast for three days}}
\hadithdefcmd{ibnmajah}{2135}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ رَأَى النَّبِيُّ ـ صلى الله عليه وسلم ـ شَيْخًا يَمْشِي بَيْنَ ابْنَيْهِ فَقَالَ ‏"‏ مَا شَأْنُ هَذَا ‏"‏ ‏.‏ قَالَ ابْنَاهُ نَذْرٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ارْكَبْ أَيُّهَا الشَّيْخُ فَإِنَّ اللَّهَ غَنِيٌّ عَنْكَ وَعَنْ نَذْرِكَ ‏"‏ ‏.‏\hadithno{2135}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Prophet (ﷺ) saw an old man walking between his two sons, and he said: What is the matter with him?' His sons said: 'A vow, O Messenger of Allah.' He said: 'Let this old man ride, for Allah has no need of you or your vow}}
\hadithdefcmd{ibnmajah}{2136}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا إِسْحَاقُ بْنُ مُحَمَّدٍ الْفَرْوِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ بِرَجُلٍ بِمَكَّةَ وَهُوَ قَائِمٌ فِي الشَّمْسِ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالُوا نَذَرَ أَنْ يَصُومَ وَلاَ يَسْتَظِلَّ إِلَى اللَّيْلِ وَلاَ يَتَكَلَّمَ وَلاَ يَزَالَ قَائِمًا ‏.‏ قَالَ ‏"‏ لِيَتَكَلَّمْ وَلْيَسْتَظِلَّ وَلْيَجْلِسْ وَلْيُتِمَّ صِيَامَهُ ‏"‏ ‏.‏ حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدِ بْنِ شَنَبَةَ الْوَاسِطِيُّ، حَدَّثَنَا الْعَلاَءُ بْنُ عَبْدِ الْجَبَّارِ، عَنْ وُهَيْبٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{2136}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Abbas that the :Messenger of Allah (ﷺ) passed by a man in Makkah who was standing in the sun. He said: "What is this?" They said: "He vowed to fast and not to seek shade until night comes, and not to speak, and to remain standing." He said: "Let him speak and seek shade and let him sit down, but let him complete his fast."Another chain from Ibn 'Abbas, from the Prophet (ﷺ), with similar wording. expiation for breaking an oath}}
